@@ -50,16 +50,27 @@ class Chart:
             "path": self.get_path(key_name),
         }
 
-    def to_json(self, key_name: str) -> str:
+    def to_json(self, key_name: str, only_meta:bool=False) -> str:
         assert_that(key_name).is_not_none()
-        return json.dumps({
-            "data": self.data.to_dict(),
-            "log_type": self.log_type,
-            "chart_type": self.chart_type,
-            "data_fields": self.data_fields,
-            "label_fields": self.label_fields,
-            "path": self.get_path(key_name),
-        })
+        if only_meta:
+            return json.dumps({
+                "log_type": self.log_type,
+                "chart_type": self.chart_type,
+                "data_fields": self.data_fields,
+                "label_fields": self.label_fields,
+                "path": self.get_path(key_name),
+            })
+        else:
+            return json.dumps({
+                "data": self.data.to_dict(),
+                "log_type": self.log_type,
+                "chart_type": self.chart_type,
+                "data_fields": self.data_fields,
+                "label_fields": self.label_fields,
+                "path": self.get_path(key_name),
+            })
+
+
 
     def upload_file(self, run: Run, key_name: str) -> None:
         local_path = self.get_local_path(run.run_id, key_name)
